@@ -5,7 +5,7 @@ use Moo;
 use Sub::Install;
 use Try::Tiny;
 use Carp;
-use JSON;
+use JSON::MaybeXS;
 use Data::Rx;
 use LWP::UserAgent;
 use URI;
@@ -55,12 +55,12 @@ has 'spec' => (
             open my $fh, '<', $json_spec or croak 'Cannot read the spec file';
             local $/ = undef;
             binmode $fh;
-            $spec = from_json(<$fh>);
+            $spec = decode_json(<$fh>);
             close $fh;
         }
         catch {
             try {
-                $spec = from_json($json_spec);
+                $spec = decode_json($json_spec);
             }
 
             # it is not json, so we are returning the string as is
@@ -90,10 +90,6 @@ has 'spore_rx' => (
     }
 );
 
-has 'http_options' => (
-    is      => 'rw',
-    default => sub { {} },
-);
 
 # Change the namespace of a given instance, so that there won't be any
 # method collision between two instances
@@ -107,7 +103,7 @@ sub BUILD {
 
 sub _build_client {
     my $self = shift;
-    return LWP::UserAgent->new( %{ $self->http_options } );
+    return LWP::UserAgent->new();
 }
 
 sub validate_spore {
@@ -124,7 +120,7 @@ sub validate_spore {
     else {
         croak "Spore schema " . $self->spore_rx . " could not be found";
     }
-    my $json_schema = from_json($spore_schema);
+    my $json_schema = decode_json($spore_schema);
     my $schema      = $rx->make_schema($json_schema);
     try {
         my $valid = $schema->assert_valid($spec);
@@ -286,26 +282,23 @@ sub generate_response {
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Net::HTTP::Knork - Lightweight implementation of Spore specification
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
     use strict;
     use warnings;
     use Net::HTTP::Knork;
-    use JSON;
-    my $spec = to_json(
+    use JSON::MaybeXS;
+    my $spec = encode_json(
         {   version => 1,
             format  => [ "json", ],
             methods => {
@@ -383,10 +376,6 @@ default_params: hash specifying default parameters to pass on every requests.
 
 client: L<LWP::UserAgent> HTTP client. Automatically created if not passed.
 
-=item *
-
-http_options: options to pass to the L<LWP::UserAgent> used as a backend for Knork.
-
 =back
 
 =item make_sub_from_spec
@@ -408,7 +397,7 @@ You might want to do that if you want to create new subs with parameters you can
 
     use strict;
     use warnings;
-    use JSON;
+    use JSON::MaybeXS;
     use Net::HTTP::Knork;
     # create a client with a middleware that encode requests to json and
     # decode responses from json
@@ -419,13 +408,13 @@ You might want to do that if you want to create new subs with parameters you can
                 my $req = shift;
                 $req->header( 'Content-Type' => 'application/json' );
                 $req->header( 'Accept'       => 'application/json' );
-                $req->content( $json->encode( $req->content ) );
+                $req->content( encode_json( $req->content ) );
                 return $req;
             },
             on_response => sub {
                 my $self = shift;
                 my $resp = shift;
-                $resp->content( $json->decode( $resp->content ) );
+                $resp->content(decode_json( $resp->content ) );
                 return $resp;
               }
         }
@@ -542,3 +531,4 @@ Fabrice Gabolde - <fabrice.gabolde@gmail.com>
 =back
 
 =cut
+
