@@ -138,7 +138,7 @@ sub uri {
         $path .= '?' . $query_string;
     }
 
-    $base =~ s!/$!! if $path =~ m!^/!;
+    $base =~ s/\/$// if $path =~ m/^\//;
     return URI->new( $base . $path )->canonical;
 }
 
@@ -313,19 +313,17 @@ sub finalize {
 
 1;
 
-__END__
+
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Net::HTTP::Knork::Request - HTTP request object from SPORE env hash
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -438,3 +436,7 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
